@@ -1,16 +1,22 @@
 """distributor defines the distribution strategies for img2dataset"""
 
-from multiprocessing import Pool
+from multiprocessing import get_context
 from tqdm import tqdm
 from itertools import islice, chain
 
 
 def multiprocessing_distributor(
-    processes_count, downloader, reader, _,
+    processes_count,
+    downloader,
+    reader,
+    _,
 ):
     """Distribute the work to the processes using multiprocessing"""
-    with Pool(processes_count, maxtasksperchild=5) as process_pool:
-        for _ in tqdm(process_pool.imap_unordered(downloader, reader),):
+    ctx = get_context("spawn")
+    with ctx.Pool(processes_count, maxtasksperchild=5) as process_pool:
+        for _ in tqdm(
+            process_pool.imap_unordered(downloader, reader),
+        ):
             pass
 
         process_pool.terminate()
@@ -19,7 +25,10 @@ def multiprocessing_distributor(
 
 
 def pyspark_distributor(
-    processes_count, downloader, reader, subjob_size,
+    processes_count,
+    downloader,
+    reader,
+    subjob_size,
 ):
     """Distribute the work to the processes using pyspark"""
 
